@@ -108,6 +108,7 @@ WP_VARIABLES_PREFIX = "__"
 @dataclass
 class ConfigWorkerPool:
     compute_requirement_batch_size: int = CR_BATCH_SIZE_DEFAULT
+    compute_requirement_data_file: Optional[str] = None
     idle_node_shutdown_enabled: bool = True
     idle_node_shutdown_timeout: float = 5.0
     idle_pool_shutdown_enabled: bool = True
@@ -365,24 +366,56 @@ def load_config_work_requirement() -> Optional[ConfigWorkRequirement]:
 
 def load_config_worker_pool() -> Optional[ConfigWorkerPool]:
     """
-    Load the configuration data for a Worker Pool
+    Load the configuration data for a Worker Pool or a Compute Requirement.
     """
-    try:
-        wp_section = CONFIG_TOML[WORKER_POOL_SECTION]
-    except KeyError:
+
+    # Allow the use of values in a 'computeRequirement' section, which acts
+    # as a configuration synonym for 'workerPool'. Check for duplicates.
+    wp_section = CONFIG_TOML.get(WORKER_POOL_SECTION, {})
+    cr_section = CONFIG_TOML.get(COMPUTE_REQUIREMENT_SECTION, {})
+    duplicate_keys = set(wp_section.keys()).intersection(set(cr_section.keys()))
+    if len(duplicate_keys) != 0:
+        print_error(
+            f"Duplicate keys in '{WORKER_POOL_SECTION}' and"
+            f" '{COMPUTE_REQUIREMENT_SECTION}': {duplicate_keys}"
+        )
+        exit(1)
+    wp_section.update(cr_section)
+
+    if len(wp_section) == 0:
         return ConfigWorkerPool()
+
     try:
         worker_tag = substitute_variable_str(wp_section.get(WORKER_TAG, None))
-        worker_pool_data_file = substitute_variable_str(wp_section.get(WP_DATA, None))
+        worker_pool_data_file = substitute_variable_str(
+            wp_section.get(WORKER_POOL_DATA_FILE, None)
+        )
+        compute_requirement_data_file = substitute_variable_str(
+            wp_section.get(COMPUTE_REQUIREMENT_DATA_FILE, None)
+        )
+        if (
+            worker_pool_data_file is not None
+            and compute_requirement_data_file is not None
+        ):
+            print_error(
+                f"Only one of '{WORKER_POOL_DATA_FILE}' or"
+                f" '{COMPUTE_REQUIREMENT_DATA_FILE}' should be set"
+            )
+            exit(1)
         if worker_pool_data_file is not None:
             worker_pool_data_file = pathname_relative_to_config_file(
                 worker_pool_data_file
             )
+        if compute_requirement_data_file is not None:
+            compute_requirement_data_file = pathname_relative_to_config_file(
+                compute_requirement_data_file
+            )
 
         return ConfigWorkerPool(
             compute_requirement_batch_size=wp_section.get(
                 COMPUTE_REQUIREMENT_BATCH_SIZE, CR_BATCH_SIZE_DEFAULT
             ),
+            compute_requirement_data_file=compute_requirement_data_file,
             idle_node_shutdown_enabled=wp_section.get(IDLE_NODE_SHUTDOWN_ENABLED, True),
             idle_node_shutdown_timeout=wp_section.get(IDLE_NODE_SHUTDOWN_TIMEOUT, 5.0),
             idle_pool_shutdown_enabled=wp_section.get(IDLE_POOL_SHUTDOWN_ENABLED, True),
@@ -490,8 +523,8 @@ def update_config_work_requirement(config_wr: ConfigWorkRequirement):
 
 def unpack_namespace_in_prefix(namespace: str, prefix: str) -> (str, str):
     """
-    Allow the prefix to include the namespace. Return the unpacked
-    namespace, prefix.
+    Allow the prefix to include the namespace, which can override the supplied
+    namespace. Return the unpacked (namespace, prefix) tuple.
     """
     elems = prefix.split(NAMESPACE_SEPARATOR)
     if len(elems) == 1:
